@@ -1,7 +1,7 @@
 /* filelist.c
 
 Copyright (C) 1999-2003 Tom Gilbert.
-Copyright (C) 2010-2011 Daniel Friesel.
+Copyright (C) 2010-2018 Daniel Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -37,6 +37,7 @@ gib_list *original_file_items = NULL; /* original file items from argv */
 int filelist_len = 0;
 gib_list *current_file = NULL;
 extern int errno;
+extern int sig_exit; /* exit flag from signal handler */
 
 static gib_list *rm_filelist = NULL;
 
@@ -327,6 +328,10 @@ gib_list *feh_file_info_preload(gib_list * list)
 				feh_display_status('s');
 		} else if (opt.verbose)
 			feh_display_status('.');
+		if (sig_exit) {
+			feh_display_status(0);
+			exit(sig_exit);
+		}
 	}
 	if (opt.verbose)
 		feh_display_status(0);
@@ -397,14 +402,26 @@ void feh_file_dirname(char *dst, feh_file * f, int maxlen)
 	dst[n] = '\0';
 }
 
+#ifdef HAVE_VERSCMP
+static inline int strcmp_or_strverscmp(const char *s1, const char *s2)
+{
+	if (!opt.version_sort)
+		return(strcmp(s1, s2));
+	else
+		return(strverscmp(s1, s2));
+}
+#else
+#define strcmp_or_strverscmp strcmp
+#endif
+
 int feh_cmp_filename(void *file1, void *file2)
 {
-	return(strcmp(FEH_FILE(file1)->filename, FEH_FILE(file2)->filename));
+	return(strcmp_or_strverscmp(FEH_FILE(file1)->filename, FEH_FILE(file2)->filename));
 }
 
 int feh_cmp_name(void *file1, void *file2)
 {
-	return(strcmp(FEH_FILE(file1)->name, FEH_FILE(file2)->name));
+	return(strcmp_or_strverscmp(FEH_FILE(file1)->name, FEH_FILE(file2)->name));
 }
 
 int feh_cmp_dirname(void *file1, void *file2)
@@ -413,7 +430,7 @@ int feh_cmp_dirname(void *file1, void *file2)
 	int cmp;
 	feh_file_dirname(dir1, FEH_FILE(file1), PATH_MAX);
 	feh_file_dirname(dir2, FEH_FILE(file2), PATH_MAX);
-	if ((cmp = strcmp(dir1, dir2)) != 0)
+	if ((cmp = strcmp_or_strverscmp(dir1, dir2)) != 0)
 		return(cmp);
 	return(feh_cmp_name(file1, file2));
 }
@@ -464,9 +481,17 @@ int feh_cmp_format(void *file1, void *file2)
 
 void feh_prepare_filelist(void)
 {
-	if (opt.list || opt.customlist || (opt.sort > SORT_MTIME)
-			|| opt.preload || opt.min_width || opt.min_height
-			|| (opt.max_width != UINT_MAX) || (opt.max_height != UINT_MAX)) {
+	/*
+	 * list and customlist mode as well as the somewhat more fancy sort modes
+	 * need access to file infos. Preloading them is also useful for
+	 * list/customlist as --min-dimension/--max-dimension may filter images
+	 * which should not be processed.
+	 * Finally, if --min-dimension/--max-dimension (-> opt.filter_by_dimensions)
+	 * is set and we're in thumbnail mode, we need to filter images first so
+	 * we can create a properly sized thumbnail list.
+	 */
+	if (opt.list || opt.preload || opt.customlist || (opt.sort > SORT_MTIME)
+			|| (opt.filter_by_dimensions && (opt.index || opt.thumbs || opt.bgmode))) {
 		/* For these sort options, we have to preload images */
 		filelist = feh_file_info_preload(filelist);
 		if (!gib_list_length(filelist))
@@ -554,7 +579,7 @@ gib_list *feh_read_filelist(char *filename)
 	Imlib_Load_Error err = IMLIB_LOAD_ERROR_NONE;
 	Imlib_Image tmp_im;
 	struct stat st;
-	signed short tmp_magick_timeout;
+	signed short tmp_conversion_timeout;
 
 	if (!filename)
 		return(NULL);
@@ -562,8 +587,8 @@ gib_list *feh_read_filelist(char *filename)
 	/*
 	 * feh_load_image will fail horribly if filename is not seekable
 	 */
-	tmp_magick_timeout = opt.magick_timeout;
-	opt.magick_timeout = -1;
+	tmp_conversion_timeout = opt.conversion_timeout;
+	opt.conversion_timeout = -1;
 	if (!stat(filename, &st) && S_ISREG(st.st_mode)) {
 		tmp_im = imlib_load_image_with_error_return(filename, &err);
 		if (err == IMLIB_LOAD_ERROR_NONE) {
@@ -574,7 +599,7 @@ gib_list *feh_read_filelist(char *filename)
 			return NULL;
 		}
 	}
-	opt.magick_timeout = tmp_magick_timeout;
+	opt.conversion_timeout = tmp_conversion_timeout;
 
 	errno = 0;
 
