@@ -1,7 +1,7 @@
 /* main.c
 
 Copyright (C) 1999-2003 Tom Gilbert.
-Copyright (C) 2010-2011 Daniel Friesel.
+Copyright (C) 2010-2018 Daniel Friesel.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -42,7 +42,7 @@ int main(int argc, char **argv)
 {
 	atexit(feh_clean_exit);
 
-	srand(getpid() * time(NULL) % ((unsigned int) -1));
+	srandom(getpid() * time(NULL) % ((unsigned int) -1));
 
 	setup_signal_handlers();
 	init_parse_options(argc, argv);
@@ -59,8 +59,6 @@ int main(int argc, char **argv)
 
 	if (opt.index)
 		init_index_mode();
-	else if (opt.collage)
-		init_collage_mode();
 	else if (opt.multiwindow)
 		init_multiwindow_mode();
 	else if (opt.list || opt.customlist)
@@ -87,7 +85,7 @@ int main(int argc, char **argv)
 	/* main event loop */
 	while (feh_main_iteration(1));
 
-	return(0);
+	return(sig_exit);
 }
 
 /* Return 0 to stop iterating, 1 if ok to continue. */
@@ -104,7 +102,7 @@ int feh_main_iteration(int block)
 	double t1 = 0.0, t2 = 0.0;
 	fehtimer ft;
 
-	if (window_num == 0)
+	if (window_num == 0 || sig_exit != 0)
 		return(0);
 
 	if (first) {
@@ -137,7 +135,7 @@ int feh_main_iteration(int block)
 		if (ev_handler[ev.type])
 			(*(ev_handler[ev.type])) (&ev);
 
-		if (window_num == 0)
+		if (window_num == 0 || sig_exit != 0)
 			return(0);
 	}
 	XFlush(disp);
@@ -191,7 +189,7 @@ int feh_main_iteration(int block)
 				   in that */
 				feh_handle_timer();
 			}
-			else if (count && (FD_ISSET(0, &fdset)))
+			else if ((count > 0) && (FD_ISSET(0, &fdset)))
 				feh_event_handle_stdin();
 		}
 	} else {
@@ -204,11 +202,11 @@ int feh_main_iteration(int block)
 					&& ((errno == ENOMEM) || (errno == EINVAL)
 						|| (errno == EBADF)))
 				eprintf("Connection to X display lost");
-			else if (count && (FD_ISSET(0, &fdset)))
+			else if ((count > 0) && (FD_ISSET(0, &fdset)))
 				feh_event_handle_stdin();
 		}
 	}
-	if (window_num == 0)
+	if (window_num == 0 || sig_exit != 0)
 		return(0);
 	
 	return(1);
@@ -218,7 +216,6 @@ void feh_clean_exit(void)
 {
 	delete_rm_files();
 
-	free(opt.menu_bg);
 	free(opt.menu_font);
 
 	if(disp)
