@@ -62,7 +62,6 @@ void init_parse_options(int argc, char **argv)
 	opt.scroll_step = 20;
 	opt.menu_font = estrdup(DEFAULT_MENU_FONT);
 	opt.font = NULL;
-	opt.menu_bg = estrdup(PREFIX "/share/feh/images/menubg_default.png");
 	opt.max_height = opt.max_width = UINT_MAX;
 
 	opt.start_list_at = NULL;
@@ -314,12 +313,11 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 {
 	int discard;
 	static char stropts[] =
-		"a:A:b:B:cC:dD:e:E:f:Fg:GhH:iIj:J:kK:lL:mM:nNo:O:pPqrR:sS:tT:uUvVwW:xXy:YzZ"
-		".@:^:~:):|:+:<:>:";
+		"a:A:b:B:C:dD:e:E:f:Fg:GhH:iIj:J:kK:lL:mM:nNo:O:pPqrR:sS:tT:uUvVwW:xXy:YzZ"
+		".@:^:~:|:+:<:>:";
 
 	/* (*name, has_arg, *flag, val) See: struct option in getopts.h */
 	static struct option lopts[] = {
-		{"menu-bg"       , 1, 0, ')'},
 		{"debug"         , 0, 0, '+'},
 		{"scale-down"    , 0, 0, '.'},
 		{"max-dimension" , 1, 0, '<'},
@@ -354,7 +352,6 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"title"         , 1, 0, '^'},
 		{"alpha"         , 1, 0, 'a'},
 		{"bg"            , 1, 0, 'b'},
-		{"collage"       , 0, 0, 'c'},
 		{"draw-filename" , 0, 0, 'd'},
 		{"font"          , 1, 0, 'e'},
 		{"filelist"      , 1, 0, 'f'},
@@ -399,11 +396,11 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		{"bg-fill"       , 0, 0, 218},
 		{"bg-max"        , 0, 0, 219},
 		{"no-jump-on-resort", 0, 0, 220},
+		{"edit"          , 0, 0, 221},
 #ifdef HAVE_LIBEXIF
 		{"draw-exif"     , 0, 0, 223},
 		{"auto-rotate"   , 0, 0, 242},
 #endif
-		{"cycle-once"    , 0, 0, 224},
 		{"no-xinerama"   , 0, 0, 225},
 		{"draw-tinted"   , 0, 0, 229},
 		{"info"          , 1, 0, 234},
@@ -428,11 +425,6 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		switch (optch) {
 		case 0:
 			break;
-		case ')':
-			free(opt.menu_bg);
-			opt.menu_bg = estrdup(optarg);
-			weprintf("The --menu-bg option is deprecated and will be removed by 2012");
-			break;
 		case '+':
 			opt.debug = 1;
 			break;
@@ -578,9 +570,6 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			opt.bg = 1;
 			opt.bg_file = estrdup(optarg);
 			break;
-		case 'c':
-			opt.collage = 1;
-			break;
 		case 'd':
 			opt.draw_filename = 1;
 			break;
@@ -734,6 +723,9 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 		case 220:
 			opt.jump_on_resort = 0;
 			break;
+		case 221:
+			opt.edit = 1;
+			break;
 #ifdef HAVE_LIBEXIF
 		case 223:
 			opt.draw_exif = 1;
@@ -742,10 +734,6 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			opt.auto_rotate = 1;
 			break;
 #endif
-		case 224:
-			weprintf("--cycle-once is deprecated, please use --on-last-slide=quit instead");
-			opt.on_last_slide = ON_LAST_SLIDE_QUIT;
-			break;
 		case 225:
 			opt.xinerama = 0;
 			break;
@@ -824,6 +812,19 @@ static void feh_parse_option_array(int argc, char **argv, int finalrun)
 			add_file_to_filelist_recursively(argv[optind++], FILELIST_FIRST);
 		}
 	}
+	else if (finalrun && !opt.filelistfile && !opt.bgmode) {
+		if (opt.start_list_at && !path_is_url(opt.start_list_at) && strrchr(opt.start_list_at, '/')) {
+			char *target_directory = estrdup(opt.start_list_at);
+			char *filename_start = strrchr(target_directory, '/');
+			if (filename_start) {
+				*filename_start = '\0';
+			}
+			add_file_to_filelist_recursively(target_directory, FILELIST_FIRST);
+			free(target_directory);
+		} else {
+			add_file_to_filelist_recursively(".", FILELIST_FIRST);
+		}
+	}
 	else if (finalrun && !opt.filelistfile && !opt.bgmode)
 		add_file_to_filelist_recursively(".", FILELIST_FIRST);
 
@@ -853,17 +854,11 @@ static void check_options(void)
 		}
 	}
 
-	if ((opt.index + opt.collage) > 1) {
-		weprintf("you can't use collage mode and index mode together.\n"
-				"   I'm going with index");
-		opt.collage = 0;
-	}
-
 	if (opt.full_screen && opt.multiwindow) {
 		eprintf("You cannot combine --fullscreen with --multiwindow");
 	}
 
-	if (opt.list && (opt.multiwindow || opt.index || opt.collage)) {
+	if (opt.list && (opt.multiwindow || opt.index)) {
 		eprintf("You cannot combine --list with other modes");
 	}
 
@@ -899,6 +894,10 @@ static void show_version(void)
 		"stat64 "
 #endif
 
+#ifdef HAVE_VERSCMP
+		"verscmp "
+#endif
+
 #ifdef HAVE_LIBXINERAMA
 		"xinerama "
 #endif
